Unit PRNCode;

{=============================================================================================================================}
    INTERFACE
{=============================================================================================================================}

Uses
    SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls, Forms,
    Dialogs, GTLPrn, ExtCtrls, Buttons, StdCtrls, Spin, INFCode;

Type
    TPRNForm = Class(TForm)
        BZoomHeight: TSpeedButton;
        BtnClose: TSpeedButton;
        BtnPrint: TSpeedButton;
        BtnPrnSetup: TSpeedButton;
        BtnZoom100: TSpeedButton;
        BtnZoom150: TSpeedButton;
        BtnZoom200: TSpeedButton;
        BtnZoom50: TSpeedButton;
        BtnZoom75: TSpeedButton;
        BtnZoomWidth: TSpeedButton;
        ButtonPanel: TPanel;
        GTPreview: TGTPreview;
        GTPrinter: TGTPrinter;
        Label1: TLabel;
        PageNo: TSpinEdit;
        PrintDlg: TPrintDialog;
        PrnSetupDlg: TPrinterSetupDialog;
        BtnInfo: TSpeedButton;
        Procedure   FormClose(Sender: TObject; var Action: TCloseAction);
        Procedure   FormCreate(Sender: TObject);
        Procedure   GTPrinterBeginPage(Sender: TObject; PageNum : Integer);
        Procedure   BtnZoom200Click(Sender: TObject);
        Procedure   BtnZoom150Click(Sender: TObject);
        Procedure   BtnZoom100Click(Sender: TObject);
        Procedure   BtnZoom75Click(Sender: TObject);
        Procedure   BtnZoom50Click(Sender: TObject);
        Procedure   BtnZoomWidthClick(Sender: TObject);
        Procedure   BZoomHeightClick(Sender: TObject);
        Procedure   PageNoChange(Sender: TObject);
        Procedure   BtnPrnSetupClick(Sender: TObject);
        Procedure   BtnPrintClick(Sender: TObject);
        Procedure   BtnInfoClick(Sender: TObject);
        Procedure   BtnCloseClick(Sender: TObject);
    private
        { Private declarations }
    public
        { Public declarations }
        Procedure   MakePages;
    end;

Var
    PRNForm : TPRNForm;

{=============================================================================================================================}
    IMPLEMENTATION
{=============================================================================================================================}

{$R *.DFM}

Procedure   TPRNForm.FormClose(Sender: TObject; var Action: TCloseAction);
Begin
    Action := caFree;
End;    {- TPRNForm.FormClose -}

Procedure   TPRNForm.FormCreate(Sender: TObject);
Begin
    MakePages;
End;    {- TPRNForm.FormCreate -}

{-----------------------------------------------------------------------------------------------------------------------------}

Procedure   TPRNForm.GTPrinterBeginPage(Sender: TObject; PageNum : Integer);
Begin
    with GTPrinter do
    begin
        Font.Size := 8;
        PrintLeft(BottomOfPage, 'GTSoft Library : GTLPrn DEMO');
        PrintRight(BottomOfPage, Concat('Page ', IntToStr(PageNum)));
        Font.Size := 10;
        Home;
    end;
    PageNo.MaxValue := PageNum;
End;    {- TPRNForm.GTPrinterBeginPage -}

{-----------------------------------------------------------------------------------------------------------------------------}

Procedure   TPRNForm.BtnZoom200Click(Sender: TObject);
Begin
    GTPreview.Zoom := 200;
End;    {- TPRNForm.BtnZoom200Click -}

Procedure   TPRNForm.BtnZoom150Click(Sender: TObject);
Begin
    GTPreview.Zoom := 150;
End;    {- TPRNForm.BtnZoom150Click -}

Procedure   TPRNForm.BtnZoom100Click(Sender: TObject);
Begin
    GTPreview.Zoom := 100;
End;    {- TPRNForm.BtnZoom100Click -}

Procedure   TPRNForm.BtnZoom75Click(Sender: TObject);
Begin
    GTPreview.Zoom := 75;
End;    {- TPRNForm.BtnZoom75Click -}

Procedure   TPRNForm.BtnZoom50Click(Sender: TObject);
Begin
    GTPreview.Zoom := 50;
End;    {- TPRNForm.BtnZoom50Click -}

Procedure   TPRNForm.BtnZoomWidthClick(Sender: TObject);
Begin
    GTPreview.FitWidth;
End;    {- TPRNForm.BtnZoomWidthClick -}

Procedure   TPRNForm.BZoomHeightClick(Sender: TObject);
Begin
    GTPreview.FitHeight;
End;    {- TPRNForm.BZoomHeightClick -}

Procedure   TPRNForm.PageNoChange(Sender: TObject);
Begin
    GTPreview.PageIndex := PageNo.Value;
End;    {- TPRNForm.PageNoChange -}

Procedure   TPRNForm.BtnPrnSetupClick(Sender: TObject);
Begin
    PrnSetupDlg.Execute;
    Screen.Cursor := crHourglass;
    MakePages;
    Screen.Cursor := crDefault;
End;    {- TPRNForm.BtnPrnSetupClick -}

Procedure   TPRNForm.BtnPrintClick(Sender: TObject);
Begin
    PrintDlg.MinPage := 1;
    PrintDlg.MaxPage := GTPrinter.PageCount;
    if PrintDlg.Execute then
        case PrintDlg.PrintRange of
            prAllPages  :   GTPrinter.PrintPages(0, 0);
            prSelection :   GTPrinter.PrintPages(PageNo.Value, PageNo.Value);
            prPageNums  :   GTPrinter.PrintPages(PrintDlg.FromPage, PrintDlg.ToPage);
        end;
End;    {- TPRNForm.BtnPrintClick -}

Procedure   TPRNForm.BtnInfoClick(Sender: TObject);
Begin
    INFDialog.ShowModal;
End;    {- TPRNForm.BtnInfoClick -}

Procedure   TPRNForm.BtnCloseClick(Sender: TObject);
Begin
    Close;
End;    {- TPRNForm.BtnCloseClick -}

{-----------------------------------------------------------------------------------------------------------------------------}

Procedure   TPRNForm.MakePages;
Var
    Idx : Integer;
Begin
    with GTPrinter do
        for Idx := 1 to 5 do
        begin
            BeginPage;

            {- page title centered -}
            with Canvas.Font do
            begin
                Name  := 'Arial';
                Size  := 16;
                Style := [fsBold];
            end;
            PrintCenter(TopOfPage, Concat('Sample Page N', IntToStr(Idx)));

            {- some lines of text -}
            with Canvas.Font do
            begin
                Name  := 'Arial';
                Size  := 8;
                Style := [];
            end;

            Home;
            PrintLn('Row N 1');
            PrintLn('Row N 2');
            PrintLn('Row N 3');

            {- drawing -}
            DrawRect(10.0, 40.0, 30.0, 60.0);
            DrawRoundRect(20.0, 50.0, 40.0, 70.0, 5.0, 5.0);
            DrawRect(30.0, 60.0, 50.0, 80.0);
            DrawEllipse(40.0, 70.0, 60.0, 90.0);
            DrawLine(110.0, 30.0, 110.0, 50.0);
            DrawLine(100.0, 40.0, 120.0, 40.0);
            DrawText(111.0, 41.0, '110.0,40.0');

            {- simple framed table using LineDrawing font !!!! -}
            with Canvas.Font do
            begin
                Name  := 'MS LineDraw';
                Size  := 8;
                Style := [];
            end;

            AtPrint(35, 21, 'Ŀ');
            AtPrint(35, 22, '  CODE   DESCRIPTION              Q.TY ');
            AtPrint(35, 23, 'Ĵ');
            AtPrint(35, 24, ' 000001  3.5" HD Floppy Disk       100 ');
            AtPrint(35, 25, ' 000002  1.2GB EIDE Hard Disk       10 ');
            AtPrint(35, 26, ' 000003  8MB 72 pin RAM SIMM        20 ');
            AtPrint(35, 27, ' 000004  32MB 72 pin RAM SIMM       20 ');
            AtPrint(35, 28, '');

            EndPage;
        end;

    PageNo.Value := 1;
    GTPreview.PageIndex := PageNo.Value;
    GTPreview.FitWidth;
End;    {- TPRNForm.MakePages -}

{--> Unit initialization (if exist) <-----------------------------------------------------------------------------------------}
{- Begin -}
End.    {- of Unit -}
